beamprofiler.utils.data\_processing
===================================

.. automodule:: beamprofiler.utils.data_processing

   
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      get_nullPoint
      get_xPixel
      get_xResolution
      get_xWindow
      get_yPixel
      get_yResolution
      get_yWindow
      image_moments
      normal_mixture
      pre_top_hat
      raw_data
      raw_header
      remove_background
   
   

   
   
   

   
   
   



